# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTOccurrence(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'full_path_as_string': 'str',
        'root_occurrence': 'bool',
        'tail_instance_id': 'str',
        'head_instance_id': 'str',
        'occurrence_without_head': 'BTOccurrence',
        'occurrence_without_tail': 'BTOccurrence',
        'path': 'list[str]',
        'type_id': 'int',
        'connection_source': 'BTConnection',
        'export_type_name': 'str',
        'unknown_class': 'bool'
    }

    attribute_map = {
        'full_path_as_string': 'fullPathAsString',
        'root_occurrence': 'rootOccurrence',
        'tail_instance_id': 'tailInstanceId',
        'head_instance_id': 'headInstanceId',
        'occurrence_without_head': 'occurrenceWithoutHead',
        'occurrence_without_tail': 'occurrenceWithoutTail',
        'path': 'path',
        'type_id': 'typeId',
        'connection_source': 'connectionSource',
        'export_type_name': 'exportTypeName',
        'unknown_class': 'unknownClass'
    }

    def __init__(self, full_path_as_string=None, root_occurrence=None, tail_instance_id=None, head_instance_id=None, occurrence_without_head=None, occurrence_without_tail=None, path=None, type_id=None, connection_source=None, export_type_name=None, unknown_class=None):  # noqa: E501
        """BTOccurrence - a model defined in OpenAPI"""  # noqa: E501

        self._full_path_as_string = None
        self._root_occurrence = None
        self._tail_instance_id = None
        self._head_instance_id = None
        self._occurrence_without_head = None
        self._occurrence_without_tail = None
        self._path = None
        self._type_id = None
        self._connection_source = None
        self._export_type_name = None
        self._unknown_class = None
        self.discriminator = None

        if full_path_as_string is not None:
            self.full_path_as_string = full_path_as_string
        if root_occurrence is not None:
            self.root_occurrence = root_occurrence
        if tail_instance_id is not None:
            self.tail_instance_id = tail_instance_id
        if head_instance_id is not None:
            self.head_instance_id = head_instance_id
        if occurrence_without_head is not None:
            self.occurrence_without_head = occurrence_without_head
        if occurrence_without_tail is not None:
            self.occurrence_without_tail = occurrence_without_tail
        if path is not None:
            self.path = path
        if type_id is not None:
            self.type_id = type_id
        if connection_source is not None:
            self.connection_source = connection_source
        if export_type_name is not None:
            self.export_type_name = export_type_name
        if unknown_class is not None:
            self.unknown_class = unknown_class

    @property
    def full_path_as_string(self):
        """Gets the full_path_as_string of this BTOccurrence.  # noqa: E501


        :return: The full_path_as_string of this BTOccurrence.  # noqa: E501
        :rtype: str
        """
        return self._full_path_as_string

    @full_path_as_string.setter
    def full_path_as_string(self, full_path_as_string):
        """Sets the full_path_as_string of this BTOccurrence.


        :param full_path_as_string: The full_path_as_string of this BTOccurrence.  # noqa: E501
        :type: str
        """

        self._full_path_as_string = full_path_as_string

    @property
    def root_occurrence(self):
        """Gets the root_occurrence of this BTOccurrence.  # noqa: E501


        :return: The root_occurrence of this BTOccurrence.  # noqa: E501
        :rtype: bool
        """
        return self._root_occurrence

    @root_occurrence.setter
    def root_occurrence(self, root_occurrence):
        """Sets the root_occurrence of this BTOccurrence.


        :param root_occurrence: The root_occurrence of this BTOccurrence.  # noqa: E501
        :type: bool
        """

        self._root_occurrence = root_occurrence

    @property
    def tail_instance_id(self):
        """Gets the tail_instance_id of this BTOccurrence.  # noqa: E501


        :return: The tail_instance_id of this BTOccurrence.  # noqa: E501
        :rtype: str
        """
        return self._tail_instance_id

    @tail_instance_id.setter
    def tail_instance_id(self, tail_instance_id):
        """Sets the tail_instance_id of this BTOccurrence.


        :param tail_instance_id: The tail_instance_id of this BTOccurrence.  # noqa: E501
        :type: str
        """

        self._tail_instance_id = tail_instance_id

    @property
    def head_instance_id(self):
        """Gets the head_instance_id of this BTOccurrence.  # noqa: E501


        :return: The head_instance_id of this BTOccurrence.  # noqa: E501
        :rtype: str
        """
        return self._head_instance_id

    @head_instance_id.setter
    def head_instance_id(self, head_instance_id):
        """Sets the head_instance_id of this BTOccurrence.


        :param head_instance_id: The head_instance_id of this BTOccurrence.  # noqa: E501
        :type: str
        """

        self._head_instance_id = head_instance_id

    @property
    def occurrence_without_head(self):
        """Gets the occurrence_without_head of this BTOccurrence.  # noqa: E501


        :return: The occurrence_without_head of this BTOccurrence.  # noqa: E501
        :rtype: BTOccurrence
        """
        return self._occurrence_without_head

    @occurrence_without_head.setter
    def occurrence_without_head(self, occurrence_without_head):
        """Sets the occurrence_without_head of this BTOccurrence.


        :param occurrence_without_head: The occurrence_without_head of this BTOccurrence.  # noqa: E501
        :type: BTOccurrence
        """

        self._occurrence_without_head = occurrence_without_head

    @property
    def occurrence_without_tail(self):
        """Gets the occurrence_without_tail of this BTOccurrence.  # noqa: E501


        :return: The occurrence_without_tail of this BTOccurrence.  # noqa: E501
        :rtype: BTOccurrence
        """
        return self._occurrence_without_tail

    @occurrence_without_tail.setter
    def occurrence_without_tail(self, occurrence_without_tail):
        """Sets the occurrence_without_tail of this BTOccurrence.


        :param occurrence_without_tail: The occurrence_without_tail of this BTOccurrence.  # noqa: E501
        :type: BTOccurrence
        """

        self._occurrence_without_tail = occurrence_without_tail

    @property
    def path(self):
        """Gets the path of this BTOccurrence.  # noqa: E501


        :return: The path of this BTOccurrence.  # noqa: E501
        :rtype: list[str]
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this BTOccurrence.


        :param path: The path of this BTOccurrence.  # noqa: E501
        :type: list[str]
        """

        self._path = path

    @property
    def type_id(self):
        """Gets the type_id of this BTOccurrence.  # noqa: E501


        :return: The type_id of this BTOccurrence.  # noqa: E501
        :rtype: int
        """
        return self._type_id

    @type_id.setter
    def type_id(self, type_id):
        """Sets the type_id of this BTOccurrence.


        :param type_id: The type_id of this BTOccurrence.  # noqa: E501
        :type: int
        """

        self._type_id = type_id

    @property
    def connection_source(self):
        """Gets the connection_source of this BTOccurrence.  # noqa: E501


        :return: The connection_source of this BTOccurrence.  # noqa: E501
        :rtype: BTConnection
        """
        return self._connection_source

    @connection_source.setter
    def connection_source(self, connection_source):
        """Sets the connection_source of this BTOccurrence.


        :param connection_source: The connection_source of this BTOccurrence.  # noqa: E501
        :type: BTConnection
        """

        self._connection_source = connection_source

    @property
    def export_type_name(self):
        """Gets the export_type_name of this BTOccurrence.  # noqa: E501


        :return: The export_type_name of this BTOccurrence.  # noqa: E501
        :rtype: str
        """
        return self._export_type_name

    @export_type_name.setter
    def export_type_name(self, export_type_name):
        """Sets the export_type_name of this BTOccurrence.


        :param export_type_name: The export_type_name of this BTOccurrence.  # noqa: E501
        :type: str
        """

        self._export_type_name = export_type_name

    @property
    def unknown_class(self):
        """Gets the unknown_class of this BTOccurrence.  # noqa: E501


        :return: The unknown_class of this BTOccurrence.  # noqa: E501
        :rtype: bool
        """
        return self._unknown_class

    @unknown_class.setter
    def unknown_class(self, unknown_class):
        """Sets the unknown_class of this BTOccurrence.


        :param unknown_class: The unknown_class of this BTOccurrence.  # noqa: E501
        :type: bool
        """

        self._unknown_class = unknown_class

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTOccurrence):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTMoveElementParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'is_copy': 'bool',
        'generate_unknown_messages': 'bool',
        'need_new_version': 'bool',
        'is_deep_copy': 'bool',
        'anchor_element_id': 'str',
        'description': 'str',
        'tags': 'list[str]',
        'elements': 'list[str]',
        'owner_id': 'str',
        'owner_type': 'int',
        'import_data': 'list[str]',
        'target_workspace_id': 'str',
        'element_original_to_new_map': 'dict(str, str)',
        'is_new_document': 'bool',
        'version_name': 'str',
        'target_document_id': 'str',
        'project_id': 'str',
        'parent_id': 'str',
        'is_group_anchor': 'bool',
        'is_public': 'bool',
        'source_document_id': 'str',
        'source_workspace_id': 'str',
        'owner_email': 'str'
    }

    attribute_map = {
        'name': 'name',
        'is_copy': 'isCopy',
        'generate_unknown_messages': 'generateUnknownMessages',
        'need_new_version': 'needNewVersion',
        'is_deep_copy': 'isDeepCopy',
        'anchor_element_id': 'anchorElementId',
        'description': 'description',
        'tags': 'tags',
        'elements': 'elements',
        'owner_id': 'ownerId',
        'owner_type': 'ownerType',
        'import_data': 'importData',
        'target_workspace_id': 'targetWorkspaceId',
        'element_original_to_new_map': 'elementOriginalToNewMap',
        'is_new_document': 'isNewDocument',
        'version_name': 'versionName',
        'target_document_id': 'targetDocumentId',
        'project_id': 'projectId',
        'parent_id': 'parentId',
        'is_group_anchor': 'isGroupAnchor',
        'is_public': 'isPublic',
        'source_document_id': 'sourceDocumentId',
        'source_workspace_id': 'sourceWorkspaceId',
        'owner_email': 'ownerEmail'
    }

    def __init__(self, name=None, is_copy=None, generate_unknown_messages=None, need_new_version=None, is_deep_copy=None, anchor_element_id=None, description=None, tags=None, elements=None, owner_id=None, owner_type=None, import_data=None, target_workspace_id=None, element_original_to_new_map=None, is_new_document=None, version_name=None, target_document_id=None, project_id=None, parent_id=None, is_group_anchor=None, is_public=None, source_document_id=None, source_workspace_id=None, owner_email=None):  # noqa: E501
        """BTMoveElementParams - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._is_copy = None
        self._generate_unknown_messages = None
        self._need_new_version = None
        self._is_deep_copy = None
        self._anchor_element_id = None
        self._description = None
        self._tags = None
        self._elements = None
        self._owner_id = None
        self._owner_type = None
        self._import_data = None
        self._target_workspace_id = None
        self._element_original_to_new_map = None
        self._is_new_document = None
        self._version_name = None
        self._target_document_id = None
        self._project_id = None
        self._parent_id = None
        self._is_group_anchor = None
        self._is_public = None
        self._source_document_id = None
        self._source_workspace_id = None
        self._owner_email = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if is_copy is not None:
            self.is_copy = is_copy
        if generate_unknown_messages is not None:
            self.generate_unknown_messages = generate_unknown_messages
        if need_new_version is not None:
            self.need_new_version = need_new_version
        if is_deep_copy is not None:
            self.is_deep_copy = is_deep_copy
        if anchor_element_id is not None:
            self.anchor_element_id = anchor_element_id
        if description is not None:
            self.description = description
        if tags is not None:
            self.tags = tags
        if elements is not None:
            self.elements = elements
        if owner_id is not None:
            self.owner_id = owner_id
        if owner_type is not None:
            self.owner_type = owner_type
        if import_data is not None:
            self.import_data = import_data
        if target_workspace_id is not None:
            self.target_workspace_id = target_workspace_id
        if element_original_to_new_map is not None:
            self.element_original_to_new_map = element_original_to_new_map
        if is_new_document is not None:
            self.is_new_document = is_new_document
        if version_name is not None:
            self.version_name = version_name
        if target_document_id is not None:
            self.target_document_id = target_document_id
        if project_id is not None:
            self.project_id = project_id
        if parent_id is not None:
            self.parent_id = parent_id
        if is_group_anchor is not None:
            self.is_group_anchor = is_group_anchor
        if is_public is not None:
            self.is_public = is_public
        if source_document_id is not None:
            self.source_document_id = source_document_id
        if source_workspace_id is not None:
            self.source_workspace_id = source_workspace_id
        if owner_email is not None:
            self.owner_email = owner_email

    @property
    def name(self):
        """Gets the name of this BTMoveElementParams.  # noqa: E501


        :return: The name of this BTMoveElementParams.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTMoveElementParams.


        :param name: The name of this BTMoveElementParams.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def is_copy(self):
        """Gets the is_copy of this BTMoveElementParams.  # noqa: E501


        :return: The is_copy of this BTMoveElementParams.  # noqa: E501
        :rtype: bool
        """
        return self._is_copy

    @is_copy.setter
    def is_copy(self, is_copy):
        """Sets the is_copy of this BTMoveElementParams.


        :param is_copy: The is_copy of this BTMoveElementParams.  # noqa: E501
        :type: bool
        """

        self._is_copy = is_copy

    @property
    def generate_unknown_messages(self):
        """Gets the generate_unknown_messages of this BTMoveElementParams.  # noqa: E501


        :return: The generate_unknown_messages of this BTMoveElementParams.  # noqa: E501
        :rtype: bool
        """
        return self._generate_unknown_messages

    @generate_unknown_messages.setter
    def generate_unknown_messages(self, generate_unknown_messages):
        """Sets the generate_unknown_messages of this BTMoveElementParams.


        :param generate_unknown_messages: The generate_unknown_messages of this BTMoveElementParams.  # noqa: E501
        :type: bool
        """

        self._generate_unknown_messages = generate_unknown_messages

    @property
    def need_new_version(self):
        """Gets the need_new_version of this BTMoveElementParams.  # noqa: E501


        :return: The need_new_version of this BTMoveElementParams.  # noqa: E501
        :rtype: bool
        """
        return self._need_new_version

    @need_new_version.setter
    def need_new_version(self, need_new_version):
        """Sets the need_new_version of this BTMoveElementParams.


        :param need_new_version: The need_new_version of this BTMoveElementParams.  # noqa: E501
        :type: bool
        """

        self._need_new_version = need_new_version

    @property
    def is_deep_copy(self):
        """Gets the is_deep_copy of this BTMoveElementParams.  # noqa: E501


        :return: The is_deep_copy of this BTMoveElementParams.  # noqa: E501
        :rtype: bool
        """
        return self._is_deep_copy

    @is_deep_copy.setter
    def is_deep_copy(self, is_deep_copy):
        """Sets the is_deep_copy of this BTMoveElementParams.


        :param is_deep_copy: The is_deep_copy of this BTMoveElementParams.  # noqa: E501
        :type: bool
        """

        self._is_deep_copy = is_deep_copy

    @property
    def anchor_element_id(self):
        """Gets the anchor_element_id of this BTMoveElementParams.  # noqa: E501


        :return: The anchor_element_id of this BTMoveElementParams.  # noqa: E501
        :rtype: str
        """
        return self._anchor_element_id

    @anchor_element_id.setter
    def anchor_element_id(self, anchor_element_id):
        """Sets the anchor_element_id of this BTMoveElementParams.


        :param anchor_element_id: The anchor_element_id of this BTMoveElementParams.  # noqa: E501
        :type: str
        """

        self._anchor_element_id = anchor_element_id

    @property
    def description(self):
        """Gets the description of this BTMoveElementParams.  # noqa: E501


        :return: The description of this BTMoveElementParams.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BTMoveElementParams.


        :param description: The description of this BTMoveElementParams.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def tags(self):
        """Gets the tags of this BTMoveElementParams.  # noqa: E501


        :return: The tags of this BTMoveElementParams.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this BTMoveElementParams.


        :param tags: The tags of this BTMoveElementParams.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def elements(self):
        """Gets the elements of this BTMoveElementParams.  # noqa: E501


        :return: The elements of this BTMoveElementParams.  # noqa: E501
        :rtype: list[str]
        """
        return self._elements

    @elements.setter
    def elements(self, elements):
        """Sets the elements of this BTMoveElementParams.


        :param elements: The elements of this BTMoveElementParams.  # noqa: E501
        :type: list[str]
        """

        self._elements = elements

    @property
    def owner_id(self):
        """Gets the owner_id of this BTMoveElementParams.  # noqa: E501


        :return: The owner_id of this BTMoveElementParams.  # noqa: E501
        :rtype: str
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """Sets the owner_id of this BTMoveElementParams.


        :param owner_id: The owner_id of this BTMoveElementParams.  # noqa: E501
        :type: str
        """

        self._owner_id = owner_id

    @property
    def owner_type(self):
        """Gets the owner_type of this BTMoveElementParams.  # noqa: E501


        :return: The owner_type of this BTMoveElementParams.  # noqa: E501
        :rtype: int
        """
        return self._owner_type

    @owner_type.setter
    def owner_type(self, owner_type):
        """Sets the owner_type of this BTMoveElementParams.


        :param owner_type: The owner_type of this BTMoveElementParams.  # noqa: E501
        :type: int
        """

        self._owner_type = owner_type

    @property
    def import_data(self):
        """Gets the import_data of this BTMoveElementParams.  # noqa: E501


        :return: The import_data of this BTMoveElementParams.  # noqa: E501
        :rtype: list[str]
        """
        return self._import_data

    @import_data.setter
    def import_data(self, import_data):
        """Sets the import_data of this BTMoveElementParams.


        :param import_data: The import_data of this BTMoveElementParams.  # noqa: E501
        :type: list[str]
        """

        self._import_data = import_data

    @property
    def target_workspace_id(self):
        """Gets the target_workspace_id of this BTMoveElementParams.  # noqa: E501


        :return: The target_workspace_id of this BTMoveElementParams.  # noqa: E501
        :rtype: str
        """
        return self._target_workspace_id

    @target_workspace_id.setter
    def target_workspace_id(self, target_workspace_id):
        """Sets the target_workspace_id of this BTMoveElementParams.


        :param target_workspace_id: The target_workspace_id of this BTMoveElementParams.  # noqa: E501
        :type: str
        """

        self._target_workspace_id = target_workspace_id

    @property
    def element_original_to_new_map(self):
        """Gets the element_original_to_new_map of this BTMoveElementParams.  # noqa: E501


        :return: The element_original_to_new_map of this BTMoveElementParams.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._element_original_to_new_map

    @element_original_to_new_map.setter
    def element_original_to_new_map(self, element_original_to_new_map):
        """Sets the element_original_to_new_map of this BTMoveElementParams.


        :param element_original_to_new_map: The element_original_to_new_map of this BTMoveElementParams.  # noqa: E501
        :type: dict(str, str)
        """

        self._element_original_to_new_map = element_original_to_new_map

    @property
    def is_new_document(self):
        """Gets the is_new_document of this BTMoveElementParams.  # noqa: E501


        :return: The is_new_document of this BTMoveElementParams.  # noqa: E501
        :rtype: bool
        """
        return self._is_new_document

    @is_new_document.setter
    def is_new_document(self, is_new_document):
        """Sets the is_new_document of this BTMoveElementParams.


        :param is_new_document: The is_new_document of this BTMoveElementParams.  # noqa: E501
        :type: bool
        """

        self._is_new_document = is_new_document

    @property
    def version_name(self):
        """Gets the version_name of this BTMoveElementParams.  # noqa: E501


        :return: The version_name of this BTMoveElementParams.  # noqa: E501
        :rtype: str
        """
        return self._version_name

    @version_name.setter
    def version_name(self, version_name):
        """Sets the version_name of this BTMoveElementParams.


        :param version_name: The version_name of this BTMoveElementParams.  # noqa: E501
        :type: str
        """

        self._version_name = version_name

    @property
    def target_document_id(self):
        """Gets the target_document_id of this BTMoveElementParams.  # noqa: E501


        :return: The target_document_id of this BTMoveElementParams.  # noqa: E501
        :rtype: str
        """
        return self._target_document_id

    @target_document_id.setter
    def target_document_id(self, target_document_id):
        """Sets the target_document_id of this BTMoveElementParams.


        :param target_document_id: The target_document_id of this BTMoveElementParams.  # noqa: E501
        :type: str
        """

        self._target_document_id = target_document_id

    @property
    def project_id(self):
        """Gets the project_id of this BTMoveElementParams.  # noqa: E501


        :return: The project_id of this BTMoveElementParams.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this BTMoveElementParams.


        :param project_id: The project_id of this BTMoveElementParams.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def parent_id(self):
        """Gets the parent_id of this BTMoveElementParams.  # noqa: E501


        :return: The parent_id of this BTMoveElementParams.  # noqa: E501
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """Sets the parent_id of this BTMoveElementParams.


        :param parent_id: The parent_id of this BTMoveElementParams.  # noqa: E501
        :type: str
        """

        self._parent_id = parent_id

    @property
    def is_group_anchor(self):
        """Gets the is_group_anchor of this BTMoveElementParams.  # noqa: E501


        :return: The is_group_anchor of this BTMoveElementParams.  # noqa: E501
        :rtype: bool
        """
        return self._is_group_anchor

    @is_group_anchor.setter
    def is_group_anchor(self, is_group_anchor):
        """Sets the is_group_anchor of this BTMoveElementParams.


        :param is_group_anchor: The is_group_anchor of this BTMoveElementParams.  # noqa: E501
        :type: bool
        """

        self._is_group_anchor = is_group_anchor

    @property
    def is_public(self):
        """Gets the is_public of this BTMoveElementParams.  # noqa: E501


        :return: The is_public of this BTMoveElementParams.  # noqa: E501
        :rtype: bool
        """
        return self._is_public

    @is_public.setter
    def is_public(self, is_public):
        """Sets the is_public of this BTMoveElementParams.


        :param is_public: The is_public of this BTMoveElementParams.  # noqa: E501
        :type: bool
        """

        self._is_public = is_public

    @property
    def source_document_id(self):
        """Gets the source_document_id of this BTMoveElementParams.  # noqa: E501


        :return: The source_document_id of this BTMoveElementParams.  # noqa: E501
        :rtype: str
        """
        return self._source_document_id

    @source_document_id.setter
    def source_document_id(self, source_document_id):
        """Sets the source_document_id of this BTMoveElementParams.


        :param source_document_id: The source_document_id of this BTMoveElementParams.  # noqa: E501
        :type: str
        """

        self._source_document_id = source_document_id

    @property
    def source_workspace_id(self):
        """Gets the source_workspace_id of this BTMoveElementParams.  # noqa: E501


        :return: The source_workspace_id of this BTMoveElementParams.  # noqa: E501
        :rtype: str
        """
        return self._source_workspace_id

    @source_workspace_id.setter
    def source_workspace_id(self, source_workspace_id):
        """Sets the source_workspace_id of this BTMoveElementParams.


        :param source_workspace_id: The source_workspace_id of this BTMoveElementParams.  # noqa: E501
        :type: str
        """

        self._source_workspace_id = source_workspace_id

    @property
    def owner_email(self):
        """Gets the owner_email of this BTMoveElementParams.  # noqa: E501


        :return: The owner_email of this BTMoveElementParams.  # noqa: E501
        :rtype: str
        """
        return self._owner_email

    @owner_email.setter
    def owner_email(self, owner_email):
        """Sets the owner_email of this BTMoveElementParams.


        :param owner_email: The owner_email of this BTMoveElementParams.  # noqa: E501
        :type: str
        """

        self._owner_email = owner_email

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTMoveElementParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTWorkflowStateInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'display_name': 'str',
        'required_properties': 'list[str]',
        'notifier_source_property': 'str',
        'editable_properties': 'list[str]',
        'approver_source_property': 'str'
    }

    attribute_map = {
        'name': 'name',
        'display_name': 'displayName',
        'required_properties': 'requiredProperties',
        'notifier_source_property': 'notifierSourceProperty',
        'editable_properties': 'editableProperties',
        'approver_source_property': 'approverSourceProperty'
    }

    def __init__(self, name=None, display_name=None, required_properties=None, notifier_source_property=None, editable_properties=None, approver_source_property=None):  # noqa: E501
        """BTWorkflowStateInfo - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._display_name = None
        self._required_properties = None
        self._notifier_source_property = None
        self._editable_properties = None
        self._approver_source_property = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if display_name is not None:
            self.display_name = display_name
        if required_properties is not None:
            self.required_properties = required_properties
        if notifier_source_property is not None:
            self.notifier_source_property = notifier_source_property
        if editable_properties is not None:
            self.editable_properties = editable_properties
        if approver_source_property is not None:
            self.approver_source_property = approver_source_property

    @property
    def name(self):
        """Gets the name of this BTWorkflowStateInfo.  # noqa: E501


        :return: The name of this BTWorkflowStateInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTWorkflowStateInfo.


        :param name: The name of this BTWorkflowStateInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def display_name(self):
        """Gets the display_name of this BTWorkflowStateInfo.  # noqa: E501


        :return: The display_name of this BTWorkflowStateInfo.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this BTWorkflowStateInfo.


        :param display_name: The display_name of this BTWorkflowStateInfo.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def required_properties(self):
        """Gets the required_properties of this BTWorkflowStateInfo.  # noqa: E501


        :return: The required_properties of this BTWorkflowStateInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._required_properties

    @required_properties.setter
    def required_properties(self, required_properties):
        """Sets the required_properties of this BTWorkflowStateInfo.


        :param required_properties: The required_properties of this BTWorkflowStateInfo.  # noqa: E501
        :type: list[str]
        """

        self._required_properties = required_properties

    @property
    def notifier_source_property(self):
        """Gets the notifier_source_property of this BTWorkflowStateInfo.  # noqa: E501


        :return: The notifier_source_property of this BTWorkflowStateInfo.  # noqa: E501
        :rtype: str
        """
        return self._notifier_source_property

    @notifier_source_property.setter
    def notifier_source_property(self, notifier_source_property):
        """Sets the notifier_source_property of this BTWorkflowStateInfo.


        :param notifier_source_property: The notifier_source_property of this BTWorkflowStateInfo.  # noqa: E501
        :type: str
        """

        self._notifier_source_property = notifier_source_property

    @property
    def editable_properties(self):
        """Gets the editable_properties of this BTWorkflowStateInfo.  # noqa: E501


        :return: The editable_properties of this BTWorkflowStateInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._editable_properties

    @editable_properties.setter
    def editable_properties(self, editable_properties):
        """Sets the editable_properties of this BTWorkflowStateInfo.


        :param editable_properties: The editable_properties of this BTWorkflowStateInfo.  # noqa: E501
        :type: list[str]
        """

        self._editable_properties = editable_properties

    @property
    def approver_source_property(self):
        """Gets the approver_source_property of this BTWorkflowStateInfo.  # noqa: E501


        :return: The approver_source_property of this BTWorkflowStateInfo.  # noqa: E501
        :rtype: str
        """
        return self._approver_source_property

    @approver_source_property.setter
    def approver_source_property(self, approver_source_property):
        """Sets the approver_source_property of this BTWorkflowStateInfo.


        :param approver_source_property: The approver_source_property of this BTWorkflowStateInfo.  # noqa: E501
        :type: str
        """

        self._approver_source_property = approver_source_property

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTWorkflowStateInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



"""A collection of utility functions"""


def parse_quantity(q):
    """
    Parse an Onshape units definition
    Args:
        q:an Onshape units definition... for instance:
            {
              'typeTag': '',
              'unitToPower': [
                {
                  'key': 'METER',
                  'value': 1
                }
              ],
              'value': 0.0868175271040671
            }

    Returns:
        a string that can be converted to any other unit engine.

    >>> from onshape_client.utility import parse_quantity
    >>> d = {'value': 0.1414213562373095, 'unitToPower': [{'value': 1, 'key': 'METER'}], 'typeTag': ''}
    >>> parse_quantity(d)
    '0.1414213562373095*meter'

    >>> d = {'value': 0.1414213562373095, 'unitToPower': [{'value': 3, 'key': 'MILLIMETER'}], 'typeTag': ''}
    >>> parse_quantity(d)
    '0.1414213562373095*millimeter**3'
    """
    units_s = str(q['value'])
    for u in q['unitToPower']:
        units_s = units_s + "*" + u['key'].lower()
        power = u['value']
        if not power == 1:
            units_s = units_s + "**" + str(power)
    return units_s



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTReleasePackageInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'detailed': 'bool',
        'column_names': 'dict(str, str)',
        'comments': 'list[BTCommentInfo]',
        'items': 'list[BTReleasePackageItemInfo]',
        'package_thumbnail': 'str',
        'workspace_id': 'str',
        'version_id': 'str',
        'linked_version_ids': 'list[str]',
        'revision_rule_id': 'str',
        'properties': 'list[BTWorkflowPropertyInfo]',
        'description_as_property': 'str',
        'name_as_property': 'str',
        'description': 'str',
        'workflow': 'BTWorkflowSnapshotInfo',
        'company_id': 'str',
        'document_id': 'str',
        'is_obsoletion': 'bool',
        'name': 'str',
        'id': 'str',
        'href': 'str',
        'view_ref': 'str'
    }

    attribute_map = {
        'detailed': 'detailed',
        'column_names': 'columnNames',
        'comments': 'comments',
        'items': 'items',
        'package_thumbnail': 'packageThumbnail',
        'workspace_id': 'workspaceId',
        'version_id': 'versionId',
        'linked_version_ids': 'linkedVersionIds',
        'revision_rule_id': 'revisionRuleId',
        'properties': 'properties',
        'description_as_property': 'descriptionAsProperty',
        'name_as_property': 'nameAsProperty',
        'description': 'description',
        'workflow': 'workflow',
        'company_id': 'companyId',
        'document_id': 'documentId',
        'is_obsoletion': 'isObsoletion',
        'name': 'name',
        'id': 'id',
        'href': 'href',
        'view_ref': 'viewRef'
    }

    def __init__(self, detailed=None, column_names=None, comments=None, items=None, package_thumbnail=None, workspace_id=None, version_id=None, linked_version_ids=None, revision_rule_id=None, properties=None, description_as_property=None, name_as_property=None, description=None, workflow=None, company_id=None, document_id=None, is_obsoletion=None, name=None, id=None, href=None, view_ref=None):  # noqa: E501
        """BTReleasePackageInfo - a model defined in OpenAPI"""  # noqa: E501

        self._detailed = None
        self._column_names = None
        self._comments = None
        self._items = None
        self._package_thumbnail = None
        self._workspace_id = None
        self._version_id = None
        self._linked_version_ids = None
        self._revision_rule_id = None
        self._properties = None
        self._description_as_property = None
        self._name_as_property = None
        self._description = None
        self._workflow = None
        self._company_id = None
        self._document_id = None
        self._is_obsoletion = None
        self._name = None
        self._id = None
        self._href = None
        self._view_ref = None
        self.discriminator = None

        if detailed is not None:
            self.detailed = detailed
        if column_names is not None:
            self.column_names = column_names
        if comments is not None:
            self.comments = comments
        if items is not None:
            self.items = items
        if package_thumbnail is not None:
            self.package_thumbnail = package_thumbnail
        if workspace_id is not None:
            self.workspace_id = workspace_id
        if version_id is not None:
            self.version_id = version_id
        if linked_version_ids is not None:
            self.linked_version_ids = linked_version_ids
        if revision_rule_id is not None:
            self.revision_rule_id = revision_rule_id
        if properties is not None:
            self.properties = properties
        if description_as_property is not None:
            self.description_as_property = description_as_property
        if name_as_property is not None:
            self.name_as_property = name_as_property
        if description is not None:
            self.description = description
        if workflow is not None:
            self.workflow = workflow
        if company_id is not None:
            self.company_id = company_id
        if document_id is not None:
            self.document_id = document_id
        if is_obsoletion is not None:
            self.is_obsoletion = is_obsoletion
        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if href is not None:
            self.href = href
        if view_ref is not None:
            self.view_ref = view_ref

    @property
    def detailed(self):
        """Gets the detailed of this BTReleasePackageInfo.  # noqa: E501


        :return: The detailed of this BTReleasePackageInfo.  # noqa: E501
        :rtype: bool
        """
        return self._detailed

    @detailed.setter
    def detailed(self, detailed):
        """Sets the detailed of this BTReleasePackageInfo.


        :param detailed: The detailed of this BTReleasePackageInfo.  # noqa: E501
        :type: bool
        """

        self._detailed = detailed

    @property
    def column_names(self):
        """Gets the column_names of this BTReleasePackageInfo.  # noqa: E501


        :return: The column_names of this BTReleasePackageInfo.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._column_names

    @column_names.setter
    def column_names(self, column_names):
        """Sets the column_names of this BTReleasePackageInfo.


        :param column_names: The column_names of this BTReleasePackageInfo.  # noqa: E501
        :type: dict(str, str)
        """

        self._column_names = column_names

    @property
    def comments(self):
        """Gets the comments of this BTReleasePackageInfo.  # noqa: E501


        :return: The comments of this BTReleasePackageInfo.  # noqa: E501
        :rtype: list[BTCommentInfo]
        """
        return self._comments

    @comments.setter
    def comments(self, comments):
        """Sets the comments of this BTReleasePackageInfo.


        :param comments: The comments of this BTReleasePackageInfo.  # noqa: E501
        :type: list[BTCommentInfo]
        """

        self._comments = comments

    @property
    def items(self):
        """Gets the items of this BTReleasePackageInfo.  # noqa: E501


        :return: The items of this BTReleasePackageInfo.  # noqa: E501
        :rtype: list[BTReleasePackageItemInfo]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this BTReleasePackageInfo.


        :param items: The items of this BTReleasePackageInfo.  # noqa: E501
        :type: list[BTReleasePackageItemInfo]
        """

        self._items = items

    @property
    def package_thumbnail(self):
        """Gets the package_thumbnail of this BTReleasePackageInfo.  # noqa: E501


        :return: The package_thumbnail of this BTReleasePackageInfo.  # noqa: E501
        :rtype: str
        """
        return self._package_thumbnail

    @package_thumbnail.setter
    def package_thumbnail(self, package_thumbnail):
        """Sets the package_thumbnail of this BTReleasePackageInfo.


        :param package_thumbnail: The package_thumbnail of this BTReleasePackageInfo.  # noqa: E501
        :type: str
        """

        self._package_thumbnail = package_thumbnail

    @property
    def workspace_id(self):
        """Gets the workspace_id of this BTReleasePackageInfo.  # noqa: E501


        :return: The workspace_id of this BTReleasePackageInfo.  # noqa: E501
        :rtype: str
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        """Sets the workspace_id of this BTReleasePackageInfo.


        :param workspace_id: The workspace_id of this BTReleasePackageInfo.  # noqa: E501
        :type: str
        """

        self._workspace_id = workspace_id

    @property
    def version_id(self):
        """Gets the version_id of this BTReleasePackageInfo.  # noqa: E501


        :return: The version_id of this BTReleasePackageInfo.  # noqa: E501
        :rtype: str
        """
        return self._version_id

    @version_id.setter
    def version_id(self, version_id):
        """Sets the version_id of this BTReleasePackageInfo.


        :param version_id: The version_id of this BTReleasePackageInfo.  # noqa: E501
        :type: str
        """

        self._version_id = version_id

    @property
    def linked_version_ids(self):
        """Gets the linked_version_ids of this BTReleasePackageInfo.  # noqa: E501


        :return: The linked_version_ids of this BTReleasePackageInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._linked_version_ids

    @linked_version_ids.setter
    def linked_version_ids(self, linked_version_ids):
        """Sets the linked_version_ids of this BTReleasePackageInfo.


        :param linked_version_ids: The linked_version_ids of this BTReleasePackageInfo.  # noqa: E501
        :type: list[str]
        """

        self._linked_version_ids = linked_version_ids

    @property
    def revision_rule_id(self):
        """Gets the revision_rule_id of this BTReleasePackageInfo.  # noqa: E501


        :return: The revision_rule_id of this BTReleasePackageInfo.  # noqa: E501
        :rtype: str
        """
        return self._revision_rule_id

    @revision_rule_id.setter
    def revision_rule_id(self, revision_rule_id):
        """Sets the revision_rule_id of this BTReleasePackageInfo.


        :param revision_rule_id: The revision_rule_id of this BTReleasePackageInfo.  # noqa: E501
        :type: str
        """

        self._revision_rule_id = revision_rule_id

    @property
    def properties(self):
        """Gets the properties of this BTReleasePackageInfo.  # noqa: E501


        :return: The properties of this BTReleasePackageInfo.  # noqa: E501
        :rtype: list[BTWorkflowPropertyInfo]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this BTReleasePackageInfo.


        :param properties: The properties of this BTReleasePackageInfo.  # noqa: E501
        :type: list[BTWorkflowPropertyInfo]
        """

        self._properties = properties

    @property
    def description_as_property(self):
        """Gets the description_as_property of this BTReleasePackageInfo.  # noqa: E501


        :return: The description_as_property of this BTReleasePackageInfo.  # noqa: E501
        :rtype: str
        """
        return self._description_as_property

    @description_as_property.setter
    def description_as_property(self, description_as_property):
        """Sets the description_as_property of this BTReleasePackageInfo.


        :param description_as_property: The description_as_property of this BTReleasePackageInfo.  # noqa: E501
        :type: str
        """

        self._description_as_property = description_as_property

    @property
    def name_as_property(self):
        """Gets the name_as_property of this BTReleasePackageInfo.  # noqa: E501


        :return: The name_as_property of this BTReleasePackageInfo.  # noqa: E501
        :rtype: str
        """
        return self._name_as_property

    @name_as_property.setter
    def name_as_property(self, name_as_property):
        """Sets the name_as_property of this BTReleasePackageInfo.


        :param name_as_property: The name_as_property of this BTReleasePackageInfo.  # noqa: E501
        :type: str
        """

        self._name_as_property = name_as_property

    @property
    def description(self):
        """Gets the description of this BTReleasePackageInfo.  # noqa: E501


        :return: The description of this BTReleasePackageInfo.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BTReleasePackageInfo.


        :param description: The description of this BTReleasePackageInfo.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def workflow(self):
        """Gets the workflow of this BTReleasePackageInfo.  # noqa: E501


        :return: The workflow of this BTReleasePackageInfo.  # noqa: E501
        :rtype: BTWorkflowSnapshotInfo
        """
        return self._workflow

    @workflow.setter
    def workflow(self, workflow):
        """Sets the workflow of this BTReleasePackageInfo.


        :param workflow: The workflow of this BTReleasePackageInfo.  # noqa: E501
        :type: BTWorkflowSnapshotInfo
        """

        self._workflow = workflow

    @property
    def company_id(self):
        """Gets the company_id of this BTReleasePackageInfo.  # noqa: E501


        :return: The company_id of this BTReleasePackageInfo.  # noqa: E501
        :rtype: str
        """
        return self._company_id

    @company_id.setter
    def company_id(self, company_id):
        """Sets the company_id of this BTReleasePackageInfo.


        :param company_id: The company_id of this BTReleasePackageInfo.  # noqa: E501
        :type: str
        """

        self._company_id = company_id

    @property
    def document_id(self):
        """Gets the document_id of this BTReleasePackageInfo.  # noqa: E501


        :return: The document_id of this BTReleasePackageInfo.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this BTReleasePackageInfo.


        :param document_id: The document_id of this BTReleasePackageInfo.  # noqa: E501
        :type: str
        """

        self._document_id = document_id

    @property
    def is_obsoletion(self):
        """Gets the is_obsoletion of this BTReleasePackageInfo.  # noqa: E501


        :return: The is_obsoletion of this BTReleasePackageInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_obsoletion

    @is_obsoletion.setter
    def is_obsoletion(self, is_obsoletion):
        """Sets the is_obsoletion of this BTReleasePackageInfo.


        :param is_obsoletion: The is_obsoletion of this BTReleasePackageInfo.  # noqa: E501
        :type: bool
        """

        self._is_obsoletion = is_obsoletion

    @property
    def name(self):
        """Gets the name of this BTReleasePackageInfo.  # noqa: E501


        :return: The name of this BTReleasePackageInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTReleasePackageInfo.


        :param name: The name of this BTReleasePackageInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this BTReleasePackageInfo.  # noqa: E501


        :return: The id of this BTReleasePackageInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTReleasePackageInfo.


        :param id: The id of this BTReleasePackageInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def href(self):
        """Gets the href of this BTReleasePackageInfo.  # noqa: E501


        :return: The href of this BTReleasePackageInfo.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this BTReleasePackageInfo.


        :param href: The href of this BTReleasePackageInfo.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def view_ref(self):
        """Gets the view_ref of this BTReleasePackageInfo.  # noqa: E501


        :return: The view_ref of this BTReleasePackageInfo.  # noqa: E501
        :rtype: str
        """
        return self._view_ref

    @view_ref.setter
    def view_ref(self, view_ref):
        """Sets the view_ref of this BTReleasePackageInfo.


        :param view_ref: The view_ref of this BTReleasePackageInfo.  # noqa: E501
        :type: str
        """

        self._view_ref = view_ref

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTReleasePackageInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTMatchingStandardContentHierarchyInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'list[str]',
        'standard_default': 'str',
        'category_default': 'str',
        'types_default': 'str',
        'type_default': 'str',
        'standard': 'list[str]',
        'types': 'list[str]',
        'component_document_id': 'str',
        'category': 'list[str]',
        'name': 'str',
        'id': 'str',
        'href': 'str',
        'view_ref': 'str'
    }

    attribute_map = {
        'type': 'type',
        'standard_default': 'standardDefault',
        'category_default': 'categoryDefault',
        'types_default': 'typesDefault',
        'type_default': 'typeDefault',
        'standard': 'standard',
        'types': 'types',
        'component_document_id': 'componentDocumentId',
        'category': 'category',
        'name': 'name',
        'id': 'id',
        'href': 'href',
        'view_ref': 'viewRef'
    }

    def __init__(self, type=None, standard_default=None, category_default=None, types_default=None, type_default=None, standard=None, types=None, component_document_id=None, category=None, name=None, id=None, href=None, view_ref=None):  # noqa: E501
        """BTMatchingStandardContentHierarchyInfo - a model defined in OpenAPI"""  # noqa: E501

        self._type = None
        self._standard_default = None
        self._category_default = None
        self._types_default = None
        self._type_default = None
        self._standard = None
        self._types = None
        self._component_document_id = None
        self._category = None
        self._name = None
        self._id = None
        self._href = None
        self._view_ref = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if standard_default is not None:
            self.standard_default = standard_default
        if category_default is not None:
            self.category_default = category_default
        if types_default is not None:
            self.types_default = types_default
        if type_default is not None:
            self.type_default = type_default
        if standard is not None:
            self.standard = standard
        if types is not None:
            self.types = types
        if component_document_id is not None:
            self.component_document_id = component_document_id
        if category is not None:
            self.category = category
        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if href is not None:
            self.href = href
        if view_ref is not None:
            self.view_ref = view_ref

    @property
    def type(self):
        """Gets the type of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501


        :return: The type of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this BTMatchingStandardContentHierarchyInfo.


        :param type: The type of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501
        :type: list[str]
        """

        self._type = type

    @property
    def standard_default(self):
        """Gets the standard_default of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501


        :return: The standard_default of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501
        :rtype: str
        """
        return self._standard_default

    @standard_default.setter
    def standard_default(self, standard_default):
        """Sets the standard_default of this BTMatchingStandardContentHierarchyInfo.


        :param standard_default: The standard_default of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501
        :type: str
        """

        self._standard_default = standard_default

    @property
    def category_default(self):
        """Gets the category_default of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501


        :return: The category_default of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501
        :rtype: str
        """
        return self._category_default

    @category_default.setter
    def category_default(self, category_default):
        """Sets the category_default of this BTMatchingStandardContentHierarchyInfo.


        :param category_default: The category_default of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501
        :type: str
        """

        self._category_default = category_default

    @property
    def types_default(self):
        """Gets the types_default of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501


        :return: The types_default of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501
        :rtype: str
        """
        return self._types_default

    @types_default.setter
    def types_default(self, types_default):
        """Sets the types_default of this BTMatchingStandardContentHierarchyInfo.


        :param types_default: The types_default of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501
        :type: str
        """

        self._types_default = types_default

    @property
    def type_default(self):
        """Gets the type_default of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501


        :return: The type_default of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501
        :rtype: str
        """
        return self._type_default

    @type_default.setter
    def type_default(self, type_default):
        """Sets the type_default of this BTMatchingStandardContentHierarchyInfo.


        :param type_default: The type_default of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501
        :type: str
        """

        self._type_default = type_default

    @property
    def standard(self):
        """Gets the standard of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501


        :return: The standard of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._standard

    @standard.setter
    def standard(self, standard):
        """Sets the standard of this BTMatchingStandardContentHierarchyInfo.


        :param standard: The standard of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501
        :type: list[str]
        """

        self._standard = standard

    @property
    def types(self):
        """Gets the types of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501


        :return: The types of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._types

    @types.setter
    def types(self, types):
        """Sets the types of this BTMatchingStandardContentHierarchyInfo.


        :param types: The types of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501
        :type: list[str]
        """

        self._types = types

    @property
    def component_document_id(self):
        """Gets the component_document_id of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501


        :return: The component_document_id of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501
        :rtype: str
        """
        return self._component_document_id

    @component_document_id.setter
    def component_document_id(self, component_document_id):
        """Sets the component_document_id of this BTMatchingStandardContentHierarchyInfo.


        :param component_document_id: The component_document_id of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501
        :type: str
        """

        self._component_document_id = component_document_id

    @property
    def category(self):
        """Gets the category of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501


        :return: The category of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this BTMatchingStandardContentHierarchyInfo.


        :param category: The category of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501
        :type: list[str]
        """

        self._category = category

    @property
    def name(self):
        """Gets the name of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501


        :return: The name of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTMatchingStandardContentHierarchyInfo.


        :param name: The name of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501


        :return: The id of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTMatchingStandardContentHierarchyInfo.


        :param id: The id of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def href(self):
        """Gets the href of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501


        :return: The href of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this BTMatchingStandardContentHierarchyInfo.


        :param href: The href of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def view_ref(self):
        """Gets the view_ref of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501


        :return: The view_ref of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501
        :rtype: str
        """
        return self._view_ref

    @view_ref.setter
    def view_ref(self, view_ref):
        """Sets the view_ref of this BTMatchingStandardContentHierarchyInfo.


        :param view_ref: The view_ref of this BTMatchingStandardContentHierarchyInfo.  # noqa: E501
        :type: str
        """

        self._view_ref = view_ref

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTMatchingStandardContentHierarchyInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class SubscriptionItem(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'object': 'str',
        'created': 'int',
        'plan': 'Plan',
        'quantity': 'int'
    }

    attribute_map = {
        'id': 'id',
        'object': 'object',
        'created': 'created',
        'plan': 'plan',
        'quantity': 'quantity'
    }

    def __init__(self, id=None, object=None, created=None, plan=None, quantity=None):  # noqa: E501
        """SubscriptionItem - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._object = None
        self._created = None
        self._plan = None
        self._quantity = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if object is not None:
            self.object = object
        if created is not None:
            self.created = created
        if plan is not None:
            self.plan = plan
        if quantity is not None:
            self.quantity = quantity

    @property
    def id(self):
        """Gets the id of this SubscriptionItem.  # noqa: E501


        :return: The id of this SubscriptionItem.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SubscriptionItem.


        :param id: The id of this SubscriptionItem.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def object(self):
        """Gets the object of this SubscriptionItem.  # noqa: E501


        :return: The object of this SubscriptionItem.  # noqa: E501
        :rtype: str
        """
        return self._object

    @object.setter
    def object(self, object):
        """Sets the object of this SubscriptionItem.


        :param object: The object of this SubscriptionItem.  # noqa: E501
        :type: str
        """

        self._object = object

    @property
    def created(self):
        """Gets the created of this SubscriptionItem.  # noqa: E501


        :return: The created of this SubscriptionItem.  # noqa: E501
        :rtype: int
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this SubscriptionItem.


        :param created: The created of this SubscriptionItem.  # noqa: E501
        :type: int
        """

        self._created = created

    @property
    def plan(self):
        """Gets the plan of this SubscriptionItem.  # noqa: E501


        :return: The plan of this SubscriptionItem.  # noqa: E501
        :rtype: Plan
        """
        return self._plan

    @plan.setter
    def plan(self, plan):
        """Sets the plan of this SubscriptionItem.


        :param plan: The plan of this SubscriptionItem.  # noqa: E501
        :type: Plan
        """

        self._plan = plan

    @property
    def quantity(self):
        """Gets the quantity of this SubscriptionItem.  # noqa: E501


        :return: The quantity of this SubscriptionItem.  # noqa: E501
        :rtype: int
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this SubscriptionItem.


        :param quantity: The quantity of this SubscriptionItem.  # noqa: E501
        :type: int
        """

        self._quantity = quantity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SubscriptionItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTBillingPlanInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'discount_info': 'BTDiscountInfo',
        'group': 'str',
        'trial_period_days': 'int',
        'client_id': 'str',
        'hidden': 'bool',
        'onshape_plan': 'bool',
        'description': 'str',
        'deprecated': 'bool',
        'plan_type': 'int',
        'consumable_quantity': 'int',
        'amount_cents': 'int',
        'interval': 'str',
        'application_id': 'str',
        'company_plan': 'bool',
        'name': 'str',
        'id': 'str',
        'href': 'str',
        'view_ref': 'str'
    }

    attribute_map = {
        'discount_info': 'discountInfo',
        'group': 'group',
        'trial_period_days': 'trialPeriodDays',
        'client_id': 'clientId',
        'hidden': 'hidden',
        'onshape_plan': 'onshapePlan',
        'description': 'description',
        'deprecated': 'deprecated',
        'plan_type': 'planType',
        'consumable_quantity': 'consumableQuantity',
        'amount_cents': 'amountCents',
        'interval': 'interval',
        'application_id': 'applicationId',
        'company_plan': 'companyPlan',
        'name': 'name',
        'id': 'id',
        'href': 'href',
        'view_ref': 'viewRef'
    }

    def __init__(self, discount_info=None, group=None, trial_period_days=None, client_id=None, hidden=None, onshape_plan=None, description=None, deprecated=None, plan_type=None, consumable_quantity=None, amount_cents=None, interval=None, application_id=None, company_plan=None, name=None, id=None, href=None, view_ref=None):  # noqa: E501
        """BTBillingPlanInfo - a model defined in OpenAPI"""  # noqa: E501

        self._discount_info = None
        self._group = None
        self._trial_period_days = None
        self._client_id = None
        self._hidden = None
        self._onshape_plan = None
        self._description = None
        self._deprecated = None
        self._plan_type = None
        self._consumable_quantity = None
        self._amount_cents = None
        self._interval = None
        self._application_id = None
        self._company_plan = None
        self._name = None
        self._id = None
        self._href = None
        self._view_ref = None
        self.discriminator = None

        if discount_info is not None:
            self.discount_info = discount_info
        if group is not None:
            self.group = group
        if trial_period_days is not None:
            self.trial_period_days = trial_period_days
        if client_id is not None:
            self.client_id = client_id
        if hidden is not None:
            self.hidden = hidden
        if onshape_plan is not None:
            self.onshape_plan = onshape_plan
        if description is not None:
            self.description = description
        if deprecated is not None:
            self.deprecated = deprecated
        if plan_type is not None:
            self.plan_type = plan_type
        if consumable_quantity is not None:
            self.consumable_quantity = consumable_quantity
        if amount_cents is not None:
            self.amount_cents = amount_cents
        if interval is not None:
            self.interval = interval
        if application_id is not None:
            self.application_id = application_id
        if company_plan is not None:
            self.company_plan = company_plan
        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if href is not None:
            self.href = href
        if view_ref is not None:
            self.view_ref = view_ref

    @property
    def discount_info(self):
        """Gets the discount_info of this BTBillingPlanInfo.  # noqa: E501


        :return: The discount_info of this BTBillingPlanInfo.  # noqa: E501
        :rtype: BTDiscountInfo
        """
        return self._discount_info

    @discount_info.setter
    def discount_info(self, discount_info):
        """Sets the discount_info of this BTBillingPlanInfo.


        :param discount_info: The discount_info of this BTBillingPlanInfo.  # noqa: E501
        :type: BTDiscountInfo
        """

        self._discount_info = discount_info

    @property
    def group(self):
        """Gets the group of this BTBillingPlanInfo.  # noqa: E501


        :return: The group of this BTBillingPlanInfo.  # noqa: E501
        :rtype: str
        """
        return self._group

    @group.setter
    def group(self, group):
        """Sets the group of this BTBillingPlanInfo.


        :param group: The group of this BTBillingPlanInfo.  # noqa: E501
        :type: str
        """

        self._group = group

    @property
    def trial_period_days(self):
        """Gets the trial_period_days of this BTBillingPlanInfo.  # noqa: E501


        :return: The trial_period_days of this BTBillingPlanInfo.  # noqa: E501
        :rtype: int
        """
        return self._trial_period_days

    @trial_period_days.setter
    def trial_period_days(self, trial_period_days):
        """Sets the trial_period_days of this BTBillingPlanInfo.


        :param trial_period_days: The trial_period_days of this BTBillingPlanInfo.  # noqa: E501
        :type: int
        """

        self._trial_period_days = trial_period_days

    @property
    def client_id(self):
        """Gets the client_id of this BTBillingPlanInfo.  # noqa: E501


        :return: The client_id of this BTBillingPlanInfo.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this BTBillingPlanInfo.


        :param client_id: The client_id of this BTBillingPlanInfo.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def hidden(self):
        """Gets the hidden of this BTBillingPlanInfo.  # noqa: E501


        :return: The hidden of this BTBillingPlanInfo.  # noqa: E501
        :rtype: bool
        """
        return self._hidden

    @hidden.setter
    def hidden(self, hidden):
        """Sets the hidden of this BTBillingPlanInfo.


        :param hidden: The hidden of this BTBillingPlanInfo.  # noqa: E501
        :type: bool
        """

        self._hidden = hidden

    @property
    def onshape_plan(self):
        """Gets the onshape_plan of this BTBillingPlanInfo.  # noqa: E501


        :return: The onshape_plan of this BTBillingPlanInfo.  # noqa: E501
        :rtype: bool
        """
        return self._onshape_plan

    @onshape_plan.setter
    def onshape_plan(self, onshape_plan):
        """Sets the onshape_plan of this BTBillingPlanInfo.


        :param onshape_plan: The onshape_plan of this BTBillingPlanInfo.  # noqa: E501
        :type: bool
        """

        self._onshape_plan = onshape_plan

    @property
    def description(self):
        """Gets the description of this BTBillingPlanInfo.  # noqa: E501


        :return: The description of this BTBillingPlanInfo.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BTBillingPlanInfo.


        :param description: The description of this BTBillingPlanInfo.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def deprecated(self):
        """Gets the deprecated of this BTBillingPlanInfo.  # noqa: E501


        :return: The deprecated of this BTBillingPlanInfo.  # noqa: E501
        :rtype: bool
        """
        return self._deprecated

    @deprecated.setter
    def deprecated(self, deprecated):
        """Sets the deprecated of this BTBillingPlanInfo.


        :param deprecated: The deprecated of this BTBillingPlanInfo.  # noqa: E501
        :type: bool
        """

        self._deprecated = deprecated

    @property
    def plan_type(self):
        """Gets the plan_type of this BTBillingPlanInfo.  # noqa: E501


        :return: The plan_type of this BTBillingPlanInfo.  # noqa: E501
        :rtype: int
        """
        return self._plan_type

    @plan_type.setter
    def plan_type(self, plan_type):
        """Sets the plan_type of this BTBillingPlanInfo.


        :param plan_type: The plan_type of this BTBillingPlanInfo.  # noqa: E501
        :type: int
        """

        self._plan_type = plan_type

    @property
    def consumable_quantity(self):
        """Gets the consumable_quantity of this BTBillingPlanInfo.  # noqa: E501


        :return: The consumable_quantity of this BTBillingPlanInfo.  # noqa: E501
        :rtype: int
        """
        return self._consumable_quantity

    @consumable_quantity.setter
    def consumable_quantity(self, consumable_quantity):
        """Sets the consumable_quantity of this BTBillingPlanInfo.


        :param consumable_quantity: The consumable_quantity of this BTBillingPlanInfo.  # noqa: E501
        :type: int
        """

        self._consumable_quantity = consumable_quantity

    @property
    def amount_cents(self):
        """Gets the amount_cents of this BTBillingPlanInfo.  # noqa: E501


        :return: The amount_cents of this BTBillingPlanInfo.  # noqa: E501
        :rtype: int
        """
        return self._amount_cents

    @amount_cents.setter
    def amount_cents(self, amount_cents):
        """Sets the amount_cents of this BTBillingPlanInfo.


        :param amount_cents: The amount_cents of this BTBillingPlanInfo.  # noqa: E501
        :type: int
        """

        self._amount_cents = amount_cents

    @property
    def interval(self):
        """Gets the interval of this BTBillingPlanInfo.  # noqa: E501


        :return: The interval of this BTBillingPlanInfo.  # noqa: E501
        :rtype: str
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """Sets the interval of this BTBillingPlanInfo.


        :param interval: The interval of this BTBillingPlanInfo.  # noqa: E501
        :type: str
        """

        self._interval = interval

    @property
    def application_id(self):
        """Gets the application_id of this BTBillingPlanInfo.  # noqa: E501


        :return: The application_id of this BTBillingPlanInfo.  # noqa: E501
        :rtype: str
        """
        return self._application_id

    @application_id.setter
    def application_id(self, application_id):
        """Sets the application_id of this BTBillingPlanInfo.


        :param application_id: The application_id of this BTBillingPlanInfo.  # noqa: E501
        :type: str
        """

        self._application_id = application_id

    @property
    def company_plan(self):
        """Gets the company_plan of this BTBillingPlanInfo.  # noqa: E501


        :return: The company_plan of this BTBillingPlanInfo.  # noqa: E501
        :rtype: bool
        """
        return self._company_plan

    @company_plan.setter
    def company_plan(self, company_plan):
        """Sets the company_plan of this BTBillingPlanInfo.


        :param company_plan: The company_plan of this BTBillingPlanInfo.  # noqa: E501
        :type: bool
        """

        self._company_plan = company_plan

    @property
    def name(self):
        """Gets the name of this BTBillingPlanInfo.  # noqa: E501


        :return: The name of this BTBillingPlanInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTBillingPlanInfo.


        :param name: The name of this BTBillingPlanInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this BTBillingPlanInfo.  # noqa: E501


        :return: The id of this BTBillingPlanInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTBillingPlanInfo.


        :param id: The id of this BTBillingPlanInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def href(self):
        """Gets the href of this BTBillingPlanInfo.  # noqa: E501


        :return: The href of this BTBillingPlanInfo.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this BTBillingPlanInfo.


        :param href: The href of this BTBillingPlanInfo.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def view_ref(self):
        """Gets the view_ref of this BTBillingPlanInfo.  # noqa: E501


        :return: The view_ref of this BTBillingPlanInfo.  # noqa: E501
        :rtype: str
        """
        return self._view_ref

    @view_ref.setter
    def view_ref(self, view_ref):
        """Sets the view_ref of this BTBillingPlanInfo.


        :param view_ref: The view_ref of this BTBillingPlanInfo.  # noqa: E501
        :type: str
        """

        self._view_ref = view_ref

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTBillingPlanInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



"""A custom module that enables Swagger to fully support our HMAC scheme with the API keys. This generates the correct
authentication headers for the given API call."""

import os
import random
import string
import json
import hmac
import hashlib
import base64
import urllib
import datetime
import six
from six.moves.urllib.parse import urlencode, quote_plus


def add_auth_headers(method, path, access_key, secret_key, query_params={}, headers={}):
    '''
    Creates a headers object to sign the request

    Args:
        - method (str): HTTP method
        - path (str): Request path, e.g. /api/documents. No query string
        - query (dict, default={}): Query string in key-value format
        - headers (dict, default={}): Other headers to pass in

    Returns:
        - dict: Dictionary containing all headers
    '''
    method = method.lower()
    date = datetime.datetime.utcnow().strftime('%a, %d %b %Y %H:%M:%S GMT')
    nonce = _make_nonce()
    ctype = headers['Content-Type']

    auth = _make_auth(method, date, nonce, path, access_key, secret_key, query_string=urlencode(query_params), ctype=ctype)

    req_headers = {
        'Date': date,
        'On-Nonce': nonce,
        'Authorization': auth
    }

    headers.update(req_headers)

    return headers


def _make_nonce():
    '''
    Generate a unique ID for the request, 25 chars in length

    Returns:
        - str: Cryptographic nonce
    '''

    chars = string.digits + string.ascii_letters
    nonce = ''.join(random.choice(chars) for i in range(25))

    # if self._logging:
    #     utils.log('nonce created: %s' % nonce)

    return nonce


def _make_auth(method, date, nonce, path, access_key, secret_key, query_string="", ctype='application/json'):
    '''
    Create the request signature to authenticate

    Args:
        - method (str): HTTP method
        - date (str): HTTP date header string
        - nonce (str): Cryptographic nonce
        - path (str): URL pathname
        - query (dict, default={}): URL query string in key-value pairs
        - ctype (str, default='application/json'): HTTP Content-Type
    '''

    if isinstance(secret_key, str):
        secret_key = secret_key.encode('utf-8')
    if isinstance(access_key, str):
        access_key = access_key.encode('utf-8')

    # query = urlencode(query)

    hmac_str = (method + '\n' + nonce + '\n' + date + '\n' + ctype + '\n' + path +
                '\n' + query_string + '\n').lower().encode('UTF_8')

    signature = base64.b64encode(hmac.new(secret_key, hmac_str, digestmod=hashlib.sha256).digest())
    auth = 'On ' + access_key.decode('UTF_8') + ':HmacSHA256:' + signature.decode('UTF_8')

    return auth



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Coupon(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'object': 'str',
        'amount_off': 'int',
        'created': 'int',
        'currency': 'str',
        'duration': 'str',
        'duration_in_months': 'int',
        'livemode': 'bool',
        'max_redemptions': 'int',
        'metadata': 'dict(str, str)',
        'percent_off': 'int',
        'redeem_by': 'int',
        'times_redeemed': 'int',
        'valid': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'object': 'object',
        'amount_off': 'amountOff',
        'created': 'created',
        'currency': 'currency',
        'duration': 'duration',
        'duration_in_months': 'durationInMonths',
        'livemode': 'livemode',
        'max_redemptions': 'maxRedemptions',
        'metadata': 'metadata',
        'percent_off': 'percentOff',
        'redeem_by': 'redeemBy',
        'times_redeemed': 'timesRedeemed',
        'valid': 'valid'
    }

    def __init__(self, id=None, object=None, amount_off=None, created=None, currency=None, duration=None, duration_in_months=None, livemode=None, max_redemptions=None, metadata=None, percent_off=None, redeem_by=None, times_redeemed=None, valid=None):  # noqa: E501
        """Coupon - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._object = None
        self._amount_off = None
        self._created = None
        self._currency = None
        self._duration = None
        self._duration_in_months = None
        self._livemode = None
        self._max_redemptions = None
        self._metadata = None
        self._percent_off = None
        self._redeem_by = None
        self._times_redeemed = None
        self._valid = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if object is not None:
            self.object = object
        if amount_off is not None:
            self.amount_off = amount_off
        if created is not None:
            self.created = created
        if currency is not None:
            self.currency = currency
        if duration is not None:
            self.duration = duration
        if duration_in_months is not None:
            self.duration_in_months = duration_in_months
        if livemode is not None:
            self.livemode = livemode
        if max_redemptions is not None:
            self.max_redemptions = max_redemptions
        if metadata is not None:
            self.metadata = metadata
        if percent_off is not None:
            self.percent_off = percent_off
        if redeem_by is not None:
            self.redeem_by = redeem_by
        if times_redeemed is not None:
            self.times_redeemed = times_redeemed
        if valid is not None:
            self.valid = valid

    @property
    def id(self):
        """Gets the id of this Coupon.  # noqa: E501


        :return: The id of this Coupon.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Coupon.


        :param id: The id of this Coupon.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def object(self):
        """Gets the object of this Coupon.  # noqa: E501


        :return: The object of this Coupon.  # noqa: E501
        :rtype: str
        """
        return self._object

    @object.setter
    def object(self, object):
        """Sets the object of this Coupon.


        :param object: The object of this Coupon.  # noqa: E501
        :type: str
        """

        self._object = object

    @property
    def amount_off(self):
        """Gets the amount_off of this Coupon.  # noqa: E501


        :return: The amount_off of this Coupon.  # noqa: E501
        :rtype: int
        """
        return self._amount_off

    @amount_off.setter
    def amount_off(self, amount_off):
        """Sets the amount_off of this Coupon.


        :param amount_off: The amount_off of this Coupon.  # noqa: E501
        :type: int
        """

        self._amount_off = amount_off

    @property
    def created(self):
        """Gets the created of this Coupon.  # noqa: E501


        :return: The created of this Coupon.  # noqa: E501
        :rtype: int
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this Coupon.


        :param created: The created of this Coupon.  # noqa: E501
        :type: int
        """

        self._created = created

    @property
    def currency(self):
        """Gets the currency of this Coupon.  # noqa: E501


        :return: The currency of this Coupon.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this Coupon.


        :param currency: The currency of this Coupon.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def duration(self):
        """Gets the duration of this Coupon.  # noqa: E501


        :return: The duration of this Coupon.  # noqa: E501
        :rtype: str
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this Coupon.


        :param duration: The duration of this Coupon.  # noqa: E501
        :type: str
        """

        self._duration = duration

    @property
    def duration_in_months(self):
        """Gets the duration_in_months of this Coupon.  # noqa: E501


        :return: The duration_in_months of this Coupon.  # noqa: E501
        :rtype: int
        """
        return self._duration_in_months

    @duration_in_months.setter
    def duration_in_months(self, duration_in_months):
        """Sets the duration_in_months of this Coupon.


        :param duration_in_months: The duration_in_months of this Coupon.  # noqa: E501
        :type: int
        """

        self._duration_in_months = duration_in_months

    @property
    def livemode(self):
        """Gets the livemode of this Coupon.  # noqa: E501


        :return: The livemode of this Coupon.  # noqa: E501
        :rtype: bool
        """
        return self._livemode

    @livemode.setter
    def livemode(self, livemode):
        """Sets the livemode of this Coupon.


        :param livemode: The livemode of this Coupon.  # noqa: E501
        :type: bool
        """

        self._livemode = livemode

    @property
    def max_redemptions(self):
        """Gets the max_redemptions of this Coupon.  # noqa: E501


        :return: The max_redemptions of this Coupon.  # noqa: E501
        :rtype: int
        """
        return self._max_redemptions

    @max_redemptions.setter
    def max_redemptions(self, max_redemptions):
        """Sets the max_redemptions of this Coupon.


        :param max_redemptions: The max_redemptions of this Coupon.  # noqa: E501
        :type: int
        """

        self._max_redemptions = max_redemptions

    @property
    def metadata(self):
        """Gets the metadata of this Coupon.  # noqa: E501


        :return: The metadata of this Coupon.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this Coupon.


        :param metadata: The metadata of this Coupon.  # noqa: E501
        :type: dict(str, str)
        """

        self._metadata = metadata

    @property
    def percent_off(self):
        """Gets the percent_off of this Coupon.  # noqa: E501


        :return: The percent_off of this Coupon.  # noqa: E501
        :rtype: int
        """
        return self._percent_off

    @percent_off.setter
    def percent_off(self, percent_off):
        """Sets the percent_off of this Coupon.


        :param percent_off: The percent_off of this Coupon.  # noqa: E501
        :type: int
        """

        self._percent_off = percent_off

    @property
    def redeem_by(self):
        """Gets the redeem_by of this Coupon.  # noqa: E501


        :return: The redeem_by of this Coupon.  # noqa: E501
        :rtype: int
        """
        return self._redeem_by

    @redeem_by.setter
    def redeem_by(self, redeem_by):
        """Sets the redeem_by of this Coupon.


        :param redeem_by: The redeem_by of this Coupon.  # noqa: E501
        :type: int
        """

        self._redeem_by = redeem_by

    @property
    def times_redeemed(self):
        """Gets the times_redeemed of this Coupon.  # noqa: E501


        :return: The times_redeemed of this Coupon.  # noqa: E501
        :rtype: int
        """
        return self._times_redeemed

    @times_redeemed.setter
    def times_redeemed(self, times_redeemed):
        """Sets the times_redeemed of this Coupon.


        :param times_redeemed: The times_redeemed of this Coupon.  # noqa: E501
        :type: int
        """

        self._times_redeemed = times_redeemed

    @property
    def valid(self):
        """Gets the valid of this Coupon.  # noqa: E501


        :return: The valid of this Coupon.  # noqa: E501
        :rtype: bool
        """
        return self._valid

    @valid.setter
    def valid(self, valid):
        """Sets the valid of this Coupon.


        :param valid: The valid of this Coupon.  # noqa: E501
        :type: bool
        """

        self._valid = valid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Coupon):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
